@@ -17,7 +17,7 @@ class Category:
     account_stock = fields.Property(fields.Many2One('account.account',
             'Account Stock', domain=[
                 ('kind', '=', 'stock'),
-                ('company', '=', Eval('context', {}).get('company', 0)),
+                ('company', '=', Eval('context', {}).get('company', -1)),
                 ],
             states={
                 'invisible': (~Eval('context', {}).get('company')
@@ -27,7 +27,7 @@ class Category:
     account_stock_supplier = fields.Property(fields.Many2One('account.account',
             'Account Stock Supplier', domain=[
                 ('kind', '=', 'stock'),
-                ('company', '=', Eval('context', {}).get('company', 0)),
+                ('company', '=', Eval('context', {}).get('company', -1)),
                 ],
             states={
                 'invisible': (~Eval('context', {}).get('company')
@@ -37,7 +37,7 @@ class Category:
     account_stock_customer = fields.Property(fields.Many2One('account.account',
             'Account Stock Customer', domain=[
                 ('kind', '=', 'stock'),
-                ('company', '=', Eval('context', {}).get('company', 0)),
+                ('company', '=', Eval('context', {}).get('company', -1)),
                 ],
             states={
                 'invisible': (~Eval('context', {}).get('company')
@@ -48,7 +48,7 @@ class Category:
         fields.Many2One('account.account',
             'Account Stock Production', domain=[
                 ('kind', '=', 'stock'),
-                ('company', '=', Eval('context', {}).get('company', 0)),
+                ('company', '=', Eval('context', {}).get('company', -1)),
                 ],
             states={
                 'invisible': (~Eval('context', {}).get('company')
@@ -58,7 +58,7 @@ class Category:
     account_stock_lost_found = fields.Property(fields.Many2One(
             'account.account', 'Account Stock Lost and Found', domain=[
                 ('kind', '=', 'stock'),
-                ('company', '=', Eval('context', {}).get('company', 0)),
+                ('company', '=', Eval('context', {}).get('company', -1)),
                 ],
             states={
                 'invisible': (~Eval('context', {}).get('company')
@@ -83,7 +83,7 @@ class Template:
             'Account Stock',
             domain=[
                 ('kind', '=', 'stock'),
-                ('company', '=', Eval('context', {}).get('company', 0)),
+                ('company', '=', Eval('context', {}).get('company', -1)),
                 ],
             states={
                 'invisible': (~Eval('context', {}).get('company')
@@ -99,7 +99,7 @@ class Template:
             'Account Stock Supplier',
             domain=[
                 ('kind', '=', 'stock'),
-                ('company', '=', Eval('context', {}).get('company', 0)),
+                ('company', '=', Eval('context', {}).get('company', -1)),
                 ],
             states={
                 'invisible': (~Eval('context', {}).get('company')
@@ -115,7 +115,7 @@ class Template:
             'Account Stock Customer',
             domain=[
                 ('kind', '=', 'stock'),
-                ('company', '=', Eval('context', {}).get('company', 0)),
+                ('company', '=', Eval('context', {}).get('company', -1)),
                 ],
             states={
                 'invisible': (~Eval('context', {}).get('company')
@@ -132,7 +132,7 @@ class Template:
             'Account Stock Production',
             domain=[
                 ('kind', '=', 'stock'),
-                ('company', '=', Eval('context', {}).get('company', 0)),
+                ('company', '=', Eval('context', {}).get('company', -1)),
                 ],
             states={
                 'invisible': (~Eval('context', {}).get('company')
@@ -148,7 +148,7 @@ class Template:
             'account.account', 'Account Stock Lost and Found',
             domain=[
                 ('kind', '=', 'stock'),
-                ('company', '=', Eval('context', {}).get('company', 0)),
+                ('company', '=', Eval('context', {}).get('company', -1)),
                 ],
             states={
                 'invisible': (~Eval('context', {}).get('company')
@@ -201,10 +201,11 @@ class UpdateCostPriceShowMove(ModelView):
         readonly=True)
     counterpart = fields.Many2One('account.account', 'Counterpart',
         domain=[
-            ('company', 'in', [Get(Eval('context', {}), 'company'), False]),
+            ('company', 'in',
+                [Eval('context', {}).get('company', -1), None]),
             ('id', '!=', Eval('stock_account')),
             ],
-        depends=['company', 'stock_account'], required=True)
+        depends=['stock_account'], required=True)
     description = fields.Char('Description')
 
 
@@ -289,7 +290,7 @@ class UpdateCostPrice(Wizard):
             }
 
     def get_move_lines(self):
-        Line = Pool.get('account.move.line')
+        Line = Pool().get('account.move.line')
         amount = self.show_move.amount
         return [Line(
                 debit=amount if amount > 0 else 0,
@@ -334,8 +335,6 @@ class UpdateCostPrice(Wizard):
         return 'update_price'
 
     def transition_update_price(self):
-        Product = Pool().get('product.product')
-        Product.write([self.ask_price.product], {
-                'cost_price': self.ask_price.cost_price,
-                })
+        self.ask_price.product.cost_price = self.ask_price.cost_price
+        self.ask_price.product.save()
         return 'end'
